==> red-7.x-1.0.tar.gz: red/templates/html.tpl.php <==
<?php

/**
 * @file
 * Default theme implementation to display the basic html structure of a single
 * Drupal page.
 *
 * @see template_preprocess()
 * @see template_preprocess_html()
 * @see template_process()
 */
?><!DOCTYPE html>
<html lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>"
<?php print $rdf_namespaces; ?>>

<head profile="<?php print $grddl_profile; ?>">
  <?php print $head; ?>
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <meta name="MobileOptimized" content="width" />
    <meta name="HandheldFriendly" content="true" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="cleartype" content="on" />
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
  <!--[if (gte IE 6)&(lte IE 8)]>
    <script src="<?php print $base_path . $path_to_resred; ?>/js/selectivizr-min.js"></script>
  <![endif]-->
  <!--[if lt IE 9]>
    <script src="<?php print $base_path . $path_to_resred; ?>/js/html5-respond.js"></script>
  <![endif]-->
<style type="text/css">
#page,
#main-wrapper,
#main-menu-links li a.active,
#main-menu-links li.active-trail a {
  background: <?php print $red_style; ?>
}
</style>
</head>
<body class="<?php print $classes; ?>" <?php print $attributes;?>>
  <div id="skip-link">
    <a href="#main-content" class="element-invisible element-focusable"><?php print t('Skip to main content'); ?></a>
  </div>
  <?php print $page_top; ?>
  <?php print $page; ?>
  <?php print $page_bottom; ?>
</body>
</html>

==> red-7.x-2.0.tar.gz: red/templates/html.tpl.php <==
<?php

/**
 * @file
 * Default theme implementation to display the basic html structure of a single
 * Drupal page.
 *
 * @see template_preprocess()
 * @see template_preprocess_html()
 * @see template_process()
 */
?><!DOCTYPE html>
<html lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>"
<?php print $rdf_namespaces; ?>>

<head profile="<?php print $grddl_profile; ?>">
  <?php print $head; ?>
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <meta name="MobileOptimized" content="width" />
    <meta name="HandheldFriendly" content="true" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="cleartype" content="on" />
  <title><?php print $head_title; ?></title>
  <?php print $styles; ?>
  <?php print $scripts; ?>
  <!--[if (gte IE 6)&(lte IE 8)]>
    <script src="<?php print $base_path . $path_to_resred; ?>/js/selectivizr-min.js"></script>
  <![endif]-->
  <!--[if lt IE 9]>
    <script src="<?php print $base_path . $path_to_resred; ?>/js/html5-respond.js"></script>
  <![endif]-->
<style type="text/css">
#page {width: <?php print $red_width; ?>;}
#page,
#main-menu-links li a.active,
#main-menu-links li.active-trail a {
  background: <?php print $red_style; ?>;}
</style>
</head>
<body class="<?php print $classes; ?>" <?php print $attributes;?>>
  <div id="skip-link">
    <a href="#main-content" class="element-invisible element-focusable"><?php print t('Skip to main content'); ?></a>
  </div>
  <?php print $page_top; ?>
  <?php print $page; ?>
  <?php print $page_bottom; ?>
</body>
</html>
